==> foundation-2.3.0.tgz: package/lib/esm/Inline.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css, useTheme } from "@emotion/react";
import { forwardRef } from "react";
import Box from "./Box";
var alignments = {
    top: "flex-start",
    bottom: "flex-end",
    center: "center",
};
export default forwardRef(function (_a, ref) {
    var _b;
    var alignY = _a.alignY, props = __rest(_a, ["alignY"]);
    var size = useTheme().size;
    return (_jsx(Box, __assign({ ref: ref }, props, { d: "flex", css: css({
            flexWrap: "wrap",
            gap: size((_b = props.gap) !== null && _b !== void 0 ? _b : "md").raw,
            alignItems: alignments[alignY !== null && alignY !== void 0 ? alignY : "top"],
        }), className: props.className })));
});

==> foundation-2.3.1.tgz: package/lib/esm/Inline.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import useTheme from "./useTheme";
import { forwardRef } from "react";
import Box from "./Box";
var alignments = {
    top: "flex-start",
    bottom: "flex-end",
    center: "center",
};
var Inline = function (_a, ref) {
    var gap = _a.gap, alignY = _a.alignY, props = __rest(_a, ["gap", "alignY"]);
    var size = useTheme().size;
    return (_jsx(Box, __assign({ ref: ref, d: "flex" }, props, { css: css({
            flexWrap: "wrap",
            gap: size(gap !== null && gap !== void 0 ? gap : "md").raw,
            alignItems: alignments[alignY !== null && alignY !== void 0 ? alignY : "top"],
        }) })));
};
export default forwardRef(Inline);
